@@ -998,14 +998,6 @@ config_str yon_config_get_all_keys_no_ignored(int *size);
 */
 int yon_config_set(char *key, void *data);
 
-/**yon_config_append(char *key, void *data)
- * [EN]
- * 
- * [RU]
- * Производит поиск по конфигу и дополняет значение параметра с ключом [key] значением [data];
-*/
-int yon_config_append(char *key, char *data, char *divider);
-
 /**yon_config_clean()
  * [EN]
  * Erase all parameters from config;
